==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/lb/resource_lb_backend/main.tf <==
/*
Пример использования
Ресурса load balancer backend
Ресурс позволяет:
1. Создавать backend
2. Редактировать backend
3. Удалять backend
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_lb_backend" "lb" {
  #id балансировщика нагрузок
  #обязательный параметр
  #тип - целое число
  lb_id = 668

  #имя бекенда для создания сервера
  #обязательный параметр
  #тип - строка
  name = "testBackend"

  #алгоритм балансировки
  #опциональный параметр
  #по умолчанию - "roundrobin"
  #доступные значения - "roundrobin", "static-rr", "leastconn"
  #тип - строка
  #algorithm = "roundrobin"

  #-------------------
  #настройки для серверов по умолчанию
  #-------------------

  #интервал между проверками, в миллисекундах
  #опциональный параметр
  #по умолчанию - 5000
  #тип - целое число
  #inter = 5000

  #интервал между проверками доступности сервера после восстановления, в миллисекундах
  #опциональный параметр
  #по умолчанию - 1000
  #тип - целое число
  #downinter = 1000

  #кол-во проверок, которые сервер должен успешно пройти
  #опциональный параметр
  #по умолчанию - 2
  #тип - целое число
  #rise = 2

  #кол-во проверок, которые сервер может не пройти и после этого получить статус "unavailable"
  #опциональный параметр
  #по умолчанию - 2
  #тип - целое число
  #fall = 2

  #кол-во миллисекунд - время между получением сервера статуса "available" и открытием соединений
  #опциональный параметр
  #по умолчанию - 60000
  #тип - целое число
  #slowstart = 60000

  #максимальное кол-во соединений сервера, при достижении этого кол-ва, сервер выходит из схемы балансирования
  #опциональный параметр
  #по умолчанию - 250
  #тип - целое число
  #maxconn = 250

  #максимальное кол-во соединений в очереди сервера, при достижении этого кол-ва, соединения будут перенаправлены на другой сервер
  #опциональный параметр
  #по умолчанию - 256
  #тип - целое число
  #maxqueue = 256

  #вес сервера для балансировки
  #опциональный параметр
  #мин - 0
  #макс - 255
  #по умолчанию - 100
  #тип - целое число
  #weight = 100
  
}

output "test" {
  value = dynamix_lb_backend.lb
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/lb/resource_lb_backend/main.tf <==
/*
Пример использования
Ресурса load balancer backend
Ресурс позволяет:
1. Создавать backend
2. Редактировать backend
3. Удалять backend
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_lb_backend" "lb" {
  #id балансировщика нагрузок
  #обязательный параметр
  #тип - целое число
  lb_id = 668

  #имя бекенда для создания сервера
  #обязательный параметр
  #тип - строка
  name = "testBackend"

  #алгоритм балансировки
  #опциональный параметр
  #по умолчанию - "roundrobin"
  #доступные значения - "roundrobin", "static-rr", "leastconn"
  #тип - строка
  #algorithm = "roundrobin"

  #-------------------
  #настройки для серверов по умолчанию
  #-------------------

  #интервал между проверками, в миллисекундах
  #опциональный параметр
  #по умолчанию - 5000
  #тип - целое число
  #inter = 5000

  #интервал между проверками доступности сервера после восстановления, в миллисекундах
  #опциональный параметр
  #по умолчанию - 1000
  #тип - целое число
  #downinter = 1000

  #кол-во проверок, которые сервер должен успешно пройти
  #опциональный параметр
  #по умолчанию - 2
  #тип - целое число
  #rise = 2

  #кол-во проверок, которые сервер может не пройти и после этого получить статус "unavailable"
  #опциональный параметр
  #по умолчанию - 2
  #тип - целое число
  #fall = 2

  #кол-во миллисекунд - время между получением сервера статуса "available" и открытием соединений
  #опциональный параметр
  #по умолчанию - 60000
  #тип - целое число
  #slowstart = 60000

  #максимальное кол-во соединений сервера, при достижении этого кол-ва, сервер выходит из схемы балансирования
  #опциональный параметр
  #по умолчанию - 250
  #тип - целое число
  #maxconn = 250

  #максимальное кол-во соединений в очереди сервера, при достижении этого кол-ва, соединения будут перенаправлены на другой сервер
  #опциональный параметр
  #по умолчанию - 256
  #тип - целое число
  #maxqueue = 256

  #вес сервера для балансировки
  #опциональный параметр
  #мин - 0
  #макс - 255
  #по умолчанию - 100
  #тип - целое число
  #weight = 100
  
}

output "test" {
  value = dynamix_lb_backend.lb
}
